@@ -72,13 +72,20 @@ def main(args):
                 print('Please run with sudo permissions.')
                 return 2
 
-            if not args.regnode:
-                if sbc.need_sudo_pw():
-                    print(
-                        'we need sudo on remote machine (without interactive authentication)'
-                    )
+            if sbc.need_sudo_pw():
+                print(
+                    'we need sudo on remote machine (without interactive authentication)'
+                )
+                return 2
+            
+            if args.regnode:
+                try:
+                    print(sbc.cmd("""sh -c "$(curl -L "https://downloads.remote.it/remoteit/install_agent.sh")""", True))
+                    return 0
+                except:
+                    print('Failed to install remote.it service')
                     return 2
-
+            else:
                 ret = pilotdriver.check_driver()
                 if ret != 0:
                     if ret == 1:
